Backends
========

.. automodule:: cumin.backends

.. rubric:: Available backends

.. toctree::

   cumin.backends.direct
   cumin.backends.knownhosts
   cumin.backends.openstack
   cumin.backends.puppetdb
